// Modules to control application life and create native browser window
const {app, BrowserWindow,ipcMain, dialog} = require('electron')
const path = require('path')
const fs = require('fs')

let filepath = path.join(__dirname, 'schema.json')

async function getSchemas() {  
  var str = fs.readFileSync(filepath,"utf8");
  var obj = JSON.parse(str)
  return obj
}

function setSchemas (event,obj) {
  var str=JSON.stringify(obj)
  fs.writeFileSync(filepath, str);
}

function createWindow () {
  // Create the browser window.
  const mainWindow = new BrowserWindow({
    width: 1600,
    height: 900,
    icon: path.join(__dirname, 'dist/logo.png'),
    webPreferences: {
      preload: path.join(__dirname, 'preload.js')
    }
  })
  mainWindow.maximize();

  // and load the index.html of the app.
  mainWindow.loadFile('./dist/index.html')

  // Open the DevTools.
  // mainWindow.webContents.openDevTools()
}

// This method will be called when Electron has finished
// initialization and is ready to create browser windows.
// Some APIs can only be used after this event occurs.
app.whenReady().then(() => {
  ipcMain.handle('schema:getSchemas', getSchemas)
  ipcMain.handle('schema:setSchemas', setSchemas)

  createWindow()
  app.on('activate', function () {
    // On macOS it's common to re-create a window in the app when the
    // dock icon is clicked and there are no other windows open.
    if (BrowserWindow.getAllWindows().length === 0) createWindow()
  })
})

// Quit when all windows are closed, except on macOS. There, it's common
// for applications and their menu bar to stay active until the user quits
// explicitly with Cmd + Q.
app.on('window-all-closed', function () {
  if (process.platform !== 'darwin') app.quit()
})

// In this file you can include the rest of your app's specific main process
// code. You can also put them in separate files and require them here.
